@@ -122,10 +122,6 @@ e_folder_exchange_new (ExchangeHierarchy *hier, const char *name,
 {
 	EFolderExchange *efe;
 	EFolder *ef;
-	char *conf_key_cal="/apps/evolution/calendar/sources";
-	char *conf_key_tasks="/apps/evolution/tasks/sources";
-	char *conf_key_contacts="/apps/evolution/addressbook/sources";
-	ESourceList *cal_source_list, *task_source_list, *cont_source_list;
 
 	g_return_val_if_fail (EXCHANGE_IS_HIERARCHY (hier), NULL);
 	g_return_val_if_fail (name != NULL, NULL);
@@ -148,48 +144,27 @@ e_folder_exchange_new (ExchangeHierarchy *hier, const char *name,
 	/* Add ESources */
 	if (hier->type == EXCHANGE_HIERARCHY_PERSONAL || 
 	    hier->type == EXCHANGE_HIERARCHY_FAVORITES) {
-	
+		
 		if ((strcmp (type, "calendar") == 0) ||
 		    (strcmp (type, "calendar/public") == 0)) {
-			cal_source_list = e_source_list_new_for_gconf ( 
-						gconf_client_get_default (), 
-						conf_key_cal);
-			add_esource (hier->account, 
-				     conf_key_cal, 
-				     name, 
-				     physical_uri, 
-				     &cal_source_list,
-				     FALSE);
-			e_source_list_sync (cal_source_list, NULL);
-			g_object_unref (cal_source_list);
+			add_folder_esource (hier->account, 
+				     	    EXCHANGE_CALENDAR_FOLDER, 
+				     	    name, 
+				     	    physical_uri);
 		}
 		else if ((strcmp (type, "tasks") == 0) ||
 			 (strcmp (type, "tasks/public") == 0)) {
-			task_source_list = e_source_list_new_for_gconf ( 
-						gconf_client_get_default (), 
-						conf_key_tasks);
-			add_esource (hier->account, 
-				     conf_key_tasks, 
-				     name, 
-				     physical_uri, 
-				     &task_source_list,
-				     FALSE);
-			e_source_list_sync (task_source_list, NULL);
-			g_object_unref (task_source_list);
+			add_folder_esource (hier->account, 
+				     	    EXCHANGE_TASKS_FOLDER, 
+				     	    name, 
+				     	    physical_uri);
 		}
 		else if ((strcmp (type, "contacts") == 0) ||
 			 (strcmp (type, "contacts/public") == 0)) {
-			cont_source_list = e_source_list_new_for_gconf ( 
-						gconf_client_get_default (), 
-						conf_key_contacts);
-			add_esource (hier->account, 
-				     conf_key_contacts, 
-				     name, 
-				     physical_uri, 
-				     &cont_source_list,
-				     TRUE);
-			e_source_list_sync (cont_source_list, NULL);
-			g_object_unref (cont_source_list);
+			add_folder_esource (hier->account, 
+				     	    EXCHANGE_CONTACTS_FOLDER, 
+				     	    name, 
+				     	    physical_uri);
 		}
 	}
 	
@@ -893,10 +868,6 @@ E2kHTTPStatus
 e_folder_exchange_delete (EFolder *folder, E2kOperation *op)
 {
 	ExchangeHierarchy *hier;
-	char *conf_key_cal="/apps/evolution/calendar/sources";
-	char *conf_key_tasks="/apps/evolution/tasks/sources";
-	char *conf_key_contacts="/apps/evolution/addressbook/sources";
-	ESourceList *cal_source_list, *task_source_list, *cont_source_list;
 	const char *folder_type, *physical_uri;
 
 	g_return_val_if_fail (E_IS_FOLDER_EXCHANGE (folder), E2K_HTTP_MALFORMED);
@@ -911,42 +882,21 @@ e_folder_exchange_delete (EFolder *folder, E2kOperation *op)
 
 		if ((strcmp (folder_type, "calendar") == 0) ||
 		    (strcmp (folder_type, "calendar/public") == 0)) {
-			cal_source_list = e_source_list_new_for_gconf (
-						gconf_client_get_default (),
-						conf_key_cal);
-			remove_esource (hier->account, 
-					conf_key_cal,
-					physical_uri,
-					&cal_source_list,
-					FALSE, FALSE);
-			e_source_list_sync (cal_source_list, NULL);
-			g_object_unref (cal_source_list);
+			remove_folder_esource (hier->account, 
+					       EXCHANGE_CALENDAR_FOLDER,
+					       physical_uri);
 		}
 		else if ((strcmp (folder_type, "tasks") == 0) ||
 			 (strcmp (folder_type, "tasks/public") == 0)) {
-			task_source_list = e_source_list_new_for_gconf (
-						gconf_client_get_default (),
-						conf_key_tasks);
-			remove_esource (hier->account,
-					conf_key_tasks,
-					physical_uri,
-					&task_source_list,
-					FALSE, FALSE);
-			e_source_list_sync (task_source_list, NULL);
-			g_object_unref (task_source_list);
+			remove_folder_esource (hier->account,
+					       EXCHANGE_TASKS_FOLDER,
+					       physical_uri);
 		}
 		else if ((strcmp (folder_type, "contacts") == 0) ||
 			 (strcmp (folder_type, "contacts/public") == 0)) { 
-			cont_source_list = e_source_list_new_for_gconf (
-						gconf_client_get_default (),
-						conf_key_contacts);
-			remove_esource (hier->account,
-					conf_key_contacts,
-					physical_uri,
-					&cont_source_list,
-					FALSE, TRUE);
-			e_source_list_sync (cont_source_list, NULL);
-			g_object_unref (cont_source_list);
+			remove_folder_esource (hier->account,
+					       EXCHANGE_CONTACTS_FOLDER,
+					       physical_uri);
 		}
 	}
 
