@@ -30,16 +30,12 @@
 #include <libedata-cal/e-data-cal-factory.h>
 #include <gconf/gconf-client.h>
 
-enum {
-        OFFLINE_MODE=1,
-        ONLINE_MODE
-};
-
 static GObjectClass *parent_class = NULL;
 
 struct _ExchangeOfflineListenerPrivate 
 {
 	GConfClient *default_client;
+	guint gconf_cnx;
 	EDataCalFactory *cal_factory;
 	EDataBookFactory *book_factory;
 	gboolean offline;
@@ -91,10 +87,10 @@ setup_offline_listener (ExchangeOfflineListener *ex_offline_listener)
 	gconf_client_add_dir (priv->default_client, "/apps/evolution/shell", 
 				GCONF_CLIENT_PRELOAD_RECURSIVE,NULL);
 
-	gconf_client_notify_add (priv->default_client, 
+	priv->gconf_cnx = gconf_client_notify_add (priv->default_client, 
 				"/apps/evolution/shell/start_offline", 
 				(GConfClientNotifyFunc)online_status_changed, 
-				ex_offline_listener, NULL, NULL);
+				(gpointer)ex_offline_listener, NULL, NULL);
 
 	value = gconf_client_get (priv->default_client, 
 				"/apps/evolution/shell/start_offline", NULL);
@@ -120,22 +116,27 @@ exchange_offline_listener_new (EDataBookFactory *book_factory, EDataCalFactory *
 }
 
 /* This returns TRUE if exchange is set offline */
-gboolean
-exchange_is_offline (ExchangeOfflineListener *ex_offline_listener)
+void
+exchange_is_offline (ExchangeOfflineListener *ex_offline_listener, int *state)
 {
 	ExchangeOfflineListenerPrivate * priv;
 
-	g_return_val_if_fail (EXCHANGE_IS_OFFLINE_LISTENER (ex_offline_listener), FALSE);
+	g_return_if_fail (EXCHANGE_IS_OFFLINE_LISTENER (ex_offline_listener));
 
 	priv = ex_offline_listener->priv;
 	
-	return priv->offline;
+	if (priv->offline)
+		*state = OFFLINE_MODE;
+	else
+		*state = ONLINE_MODE;
 }
 
 static void
 exchange_offline_listener_dispose (GObject *object)
 {
 	ExchangeOfflineListener *ex_offline_listener = EXCHANGE_OFFLINE_LISTENER (object);
+	gconf_client_notify_remove (ex_offline_listener->priv->default_client, 
+				ex_offline_listener->priv->gconf_cnx);
 	if (ex_offline_listener->priv->default_client) {
 		g_object_unref (ex_offline_listener->priv->default_client);
 		ex_offline_listener->priv->default_client = NULL;
